package com.qilesoft.en.eights.aidl;

/**
* 定义客户端与服务均认可的编程接口,以便二者使用进程间通信 (IPC) 进行相互通信。
Android SDK 工具会基于您的 .aidl 文件，使用 Java 编程语言生成接口。此接口拥有一个名为 Stub 的内部抽象类，
用于扩展 Binder 类并实现 AIDL 接口中的方法。您必须扩展 Stub 类并实现这些方法。
生成的接口包含一个名为 Stub 的子类，如：VoicePlayInterface.Stub

如要调用通过 AIDL 定义的远程接口，调用类必须执行以下步骤：
1、在项目的 src/ 目录中加入 .aidl 文件。
2、声明一个 IBinder 接口实例（基于 AIDL 生成）。YourInterfaceName.Stub binder = new YourInterfaceName.Stub()
3、实现 ServiceConnection。
4、调用 Context.bindService()，从而传入您的 ServiceConnection 实现。
5、在 onServiceConnected() 实现中，您将收到一个 IBinder 实例（名为 service）。调用 YourInterfaceName.Stub.asInterface((IBinder)service)，以将返回的参数转换为 YourInterface 类型。
6、调用您在接口上定义的方法。您应始终捕获 DeadObjectException 异常，系统会在连接中断时抛出此异常。您还应捕获 SecurityException 异常，当 IPC 方法调用中两个进程的 AIDL 定义发生冲突时，系统会抛出此异常。
7、如要断开连接，请使用您的接口实例调用 Context.unbindService()。
*/
interface IPlayAidlInterface {
        void pause();
        void play();
        void prev();
        void next();
    	void stop();
    	boolean isPlaying();
    	long duration();// 总时长
    	long getCurrentPosition();// 当前进度
    	void seekTo(long progress);// 拖动进度条

        void setPlayCirculationType(String type);// 循环类型
    	void setDataSourceAndPlay();
    	void setNowPlay(int postion);
        int getNowPlay();
    	int getOldPlayPostion();
    	String getOldClassInfoObjectId();
    	int getNotificationId();
}